==> haskell-chunked-data-0.3.1-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chunked-data
version:              0.3.1
visibility:           public
id:                   chunked-data-0.3.1-GDkSfsnhoz1BNR1TWraPg5
key:                  chunked-data-0.3.1-GDkSfsnhoz1BNR1TWraPg5
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Typeclasses for dealing with various chunked data representations

description:
    See docs and README at <http://www.stackage.org/package/chunked-data>

category:             Data
abi:                  24dbf7db7bf0d0f10c513cf39527ade2
exposed:              True
exposed-modules:      Data.Builder Data.ChunkedZip Data.IOData
hidden-modules:       Paths_chunked_data
import-dirs:          /usr/lib/ghc-8.10.1/site-local/chunked-data-0.3.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/chunked-data-0.3.1
hs-libraries:         HSchunked-data-0.3.1-GDkSfsnhoz1BNR1TWraPg5
depends:
    base-4.14.0.0 bytestring-0.10.10.0 containers-0.6.2.1 text-1.2.3.2
    transformers-0.5.6.2 vector-0.12.1.2-H0z3zqOucdK6qK7YVRJGW2

haddock-interfaces:
    /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock

haddock-html:         /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chunked-data-0.3.1-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chunked-data
version:              0.3.1
visibility:           public
id:                   chunked-data-0.3.1-4X4zPWrsgBOK0p30I4zrdg
key:                  chunked-data-0.3.1-4X4zPWrsgBOK0p30I4zrdg
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Typeclasses for dealing with various chunked data representations

description:
    See docs and README at <http://www.stackage.org/package/chunked-data>

category:             Data
abi:                  f72067099e16a2812b0963de11187360
exposed:              True
exposed-modules:      Data.Builder Data.ChunkedZip Data.IOData
hidden-modules:       Paths_chunked_data
import-dirs:          /usr/lib/ghc-8.10.1/site-local/chunked-data-0.3.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/chunked-data-0.3.1
hs-libraries:         HSchunked-data-0.3.1-4X4zPWrsgBOK0p30I4zrdg
depends:
    base-4.14.0.0 bytestring-0.10.10.0 containers-0.6.2.1 text-1.2.3.2
    transformers-0.5.6.2 vector-0.12.1.2-CYdo0xBKGbnK8ZGEF4yFOM

haddock-interfaces:
    /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock

haddock-html:         /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
